@@ -53,7 +53,7 @@ sub handler {
 			my $error_code = call_for_role ($sub_name);
 			
 			if ($error_code) {		
-				my $error_message_template = $error_messages -> {"${action}_$$page{type}_${error_code}"};
+				my $error_message_template = $error_messages -> {"${action}_$$page{type}_${error_code}"} || $error_code;
 				$_REQUEST {error} = interpolate ($error_message_template);
 			}
 			
