@@ -238,6 +238,10 @@ sub draw_hr {
 
  HTML-   C<td>.
 
+=item a_class
+
+CSS- .    C<lnk4>. 
+
 =back
 
 =head2 
@@ -250,7 +254,8 @@ sub draw_hr {
 		attributes => {
 			width => '1%',
 			align => 'right',
-		}
+		},
+		a_class => 'red_hot_link'
 	});
 
 =cut
@@ -677,6 +682,7 @@ sub draw_row_buttons {
 			{
 				name  => 'name',
 				label => ' ',
+				mandatory => 1,
 			},
 			{
 				name   => 'period',
@@ -716,6 +722,10 @@ sub draw_form {
 
  
 
+=item size
+
+  C<size>  C<maxlength>
+
 =back
 
 =cut
@@ -1007,6 +1017,10 @@ sub draw_form_field_radio {
 		{id => ' n', label => ' n'},
 	]
 
+=item empty
+
+ ,            C<id=0>.
+
 =back
 
 =cut
